Method: DeepStruct::Array#first

Defined in:
lib/deep_struct/array.rb

#firstObject

The annoyance of subclassing Array is that ruby implements many array methods directly in C, bypassing my pretty little [] method above. I expect to implement many methods like #first in the future



10
11
12
# File 'lib/deep_struct/array.rb', line 10

def first
  self[0]
end